@@ -72,6 +72,7 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
         pass
     print '\nLoaded (%s/%s)%s\n' % (loaded_ifaces, len(ifaces), loaded_list)
     self.show_all()
+#    self.__show_settings_dialog()
 
   def __show_settings_dialog(self, button=None):
     self.__config.load()
@@ -82,22 +83,46 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
     config_controls = {}
     config_keys = [key for key in self.__config.get_keys() 
                    if key.startswith('settings')]
-    config_keys.sort()
-    for config_key in config_keys:
-      name, ck_type, value = self.__config.get_entry(config_key)
-      config_options = self.__config.get_option(config_key)
-      options = ()
-      if config_options:
-        options = zip(map(self.__lcl.get, config_options), config_options)
-      config_control = self.__config_ui.create_control(self.__lcl.get(config_key), 
-                                                       ck_type, 
-                                                       (self.__lcl.get(str(value)), 
-                                                        value), 
-                                                       options)
-      if config_control:
-        config_controls[config_key] = config_control
-        wpa.pack_start(config_control, False)
-
+    config_keys_controls = set(config_keys)
+    for iface in self.__interfaces:
+      iface_name = iface.get_name()
+      iface_key = iface_name.lower()
+      wpa.pack_start(gtk.Label('%s' % iface_name))
+      iface_keys = set(key for key in config_keys_controls 
+                       if key.startswith('settings/%s/' % (iface_key)))
+      config_keys_controls -= iface_keys
+      iface_keys = list(iface_keys)
+      iface_keys.sort()
+      for config_key in iface_keys:
+        name, ck_type, value = self.__config.get_entry(config_key)
+        config_options = self.__config.get_option(config_key)
+        options = ()
+        if config_options:
+          options = zip(map(self.__lcl.get, config_options), config_options)
+        config_control = self.__config_ui.create_control(self.__lcl.get(config_key.replace('settings/%s/' % (iface_key),'',1)), 
+                                                         ck_type, 
+                                                         (self.__lcl.get(str(value)), 
+                                                          value), 
+                                                         options)
+        if config_control:
+          config_controls[config_key] = config_control
+          wpa.pack_start(config_control, False)
+    if config_keys_controls:
+      wpa.pack_start(gtk.Label(self.__lcl.get('settings-other')))
+      for config_key in config_keys_controls:
+        name, ck_type, value = self.__config.get_entry(config_key)
+        config_options = self.__config.get_option(config_key)
+        options = ()
+        if config_options:
+          options = zip(map(self.__lcl.get, config_options), config_options)
+        config_control = self.__config_ui.create_control(self.__lcl.get(config_key), 
+                                                         ck_type, 
+                                                         (self.__lcl.get(str(value)), 
+                                                          value), 
+                                                         options)
+        if config_control:
+          config_controls[config_key] = config_control
+          wpa.pack_start(config_control, False)
     about_page = gtk.VBox()
     about_page.pack_start(gtk.Label('%s %s' % (self.app_name, self.version)))
     about_page.pack_start(gtk.Label('%s%s %s <%s>' % (u'\u00A9', 
